@@ -58,19 +58,22 @@
   sharedPaths <- tryCatch({
     c(
       xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/poi-ooxml-full/5.2.5/poi-ooxml-full-5.2.5.jar"), "poi-ooxml-full.jar", 
-      "5.2.5",  libname, pkgname),
+      paste0(apachePrefix, "/poi/poi-ooxml-full/5.3.0/poi-ooxml-full-5.3.0.jar"), "poi-ooxml-full.jar", 
+      "5.3.0",  libname, pkgname),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/poi-ooxml/5.2.5/poi-ooxml-5.2.5.jar"), "poi-ooxml.jar", 
-      "5.2.5",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
+      paste0(apachePrefix, "/poi/poi-ooxml/5.3.0/poi-ooxml-5.3.0.jar"), "poi-ooxml.jar", 
+      "5.3.0",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/poi/5.2.5/poi-5.2.5.jar"), "poi.jar", 
-      "5.2.5",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
+      paste0(apachePrefix, "/poi/poi/5.3.0/poi-5.3.0.jar"), "poi.jar", 
+      "5.3.0",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/commons/commons-compress/1.25.0/commons-compress-1.25.0.jar"), "commons-compress.jar",
+      paste0(apachePrefix, "/commons/commons-compress/1.26.2/commons-compress-1.26.2.jar"), "commons-compress.jar",
       "1\\.(2[5-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg = "libcommons-compress-java", rpmpkg="apache-commons-compress"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/xmlbeans/xmlbeans/5.2.0/xmlbeans-5.2.0.jar"), "xmlbeans.jar",
+      paste0(apachePrefix, "/commons/commons-lang3/3.14.0/commons-lang3-3.14.0.jar"), "commons-lang3-3.14.0.jar",
+      "3\\.(1[4-9]|[2-9][0-9])\\.*",  libname, pkgname, debianpkg="libcommons-lang3-java", rpmpkg="apache-commons-lang3"),
+    xlcEnsureDependenciesFor(
+      paste0(apachePrefix, "/xmlbeans/xmlbeans/5.2.1/xmlbeans-5.2.1.jar"), "xmlbeans.jar",
       "5\\..*",  libname, pkgname, debianpkg="libxmlbeans-java"),
     xlcEnsureDependenciesFor(
       paste0(apachePrefix, "/commons/commons-collections4/4.4/commons-collections4-4.4.jar"), "commons-collections4.jar",
@@ -79,13 +82,13 @@
       paste0(apachePrefix, "/commons/commons-math3/3.6.1/commons-math3-3.6.1.jar"), "commons-math3.jar",
       "3\\.([6-9]|1[0-9]).*",  libname, pkgname, debianpkg="libcommons-math3-java"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/logging/log4j/log4j-api/2.21.1/log4j-api-2.21.1.jar"), "log4j-api.jar",
-      "2.21.1",  libname, pkgname),
+      paste0(apachePrefix, "/logging/log4j/log4j-api/2.23.1/log4j-api-2.23.1.jar"), "log4j-api.jar",
+      "2\\.23\\..*",  libname, pkgname),
     xlcEnsureDependenciesFor(
-      paste0(repo, "/commons-codec/commons-codec/1.16.0/commons-codec-1.16.0.jar"), "commons-codec-1.16.0.jar",
+      paste0(repo, "/commons-codec/commons-codec/1.17.0/commons-codec-1.17.0.jar"), "commons-codec-1.17.0.jar",
       "1\\.(1[1-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg="libcommons-codec-java", rpmpkg="apache-commons-codec"),
     xlcEnsureDependenciesFor(
-      paste0(repo, "/commons-io/commons-io/2.15.0/commons-io-2.15.0.jar"), "commons-io-2.15.0.jar",
+      paste0(repo, "/commons-io/commons-io/2.16.1/commons-io-2.16.1.jar"), "commons-io-2.16.1.jar",
       "2\\.(1[5-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg="libcommons-io-java", rpmpkg="apache-commons-io"),
     xlcEnsureDependenciesFor(
       paste0(repo, "/com/zaxxer/SparseBitSet/1.3/SparseBitSet-1.3.jar"), "SparseBitSet.jar",
